.. _client:

The Synth Client
================
To consume the ``synthd`` API with ``synthpy``, you have to create an
instance of the core client :class:`.Synth`.

.. currentmodule:: synthpy.client

.. autosummary::
   :toctree: api/

   Synth
   Transport
